from distutils.core import setup

setup(
    name='pymetal',
    version='0.1.6',
    packages=[],
    url='https://www.github.com/jarbasal/pymetal',
    license='MIT',
    author='jarbasAi',
    author_email='jarbasai@mailfence.com',
    description='metal archives'
)
